.. include:: ../links.inc

.. _using:

Using junifer
=============

In this section, we will cover the main aspects behind using junifer. We will first explain the basics behind junifer's
code-less configuration. Then we will show how to use the command line interface to ``run`` junifer and ``collect`` 
the results. Finally, we will show how to use the ``queue`` command to interact with HPC and HTC systems.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   codeless
   running
   queueing